@@ -1,11 +1,12 @@
-from os import system, path
+from os import makedirs, system, path, stat
 import pathlib
 from semver import VersionInfo
 from cement import Controller, ex
 from ..core.config import load_config
-from ..core.utils import create_boilerplate, get_plugin_info, get_plugin_path, show_schema
+from ..core.utils import create_boilerplate, render_boilerplate, get_plugin_info, get_plugin_path, show_schema
 from ..core.tech_local import TestLocal
 from ..core.message_log import Log
+from ..core.AWS.s3 import S3
 
 
 class CrawlerBase(Controller):
@@ -138,7 +139,6 @@ class Crawler(Controller):
             create_boilerplate(
                 plugin_path, "node_boilerplate.jinja2", data, 'js')
         else:
-
             create_boilerplate(
                 plugin_path, "php_boilerplate.jinja2", data, 'php')
 
@@ -169,6 +169,7 @@ class Crawler(Controller):
     )
     def deploy(self):
         plugin_name = self.app.pargs.plugin_name
+
         deploy_message = self.app.pargs.message
         if plugin_name is None:
             self.app.log.error(
@@ -248,3 +249,55 @@ class Crawler(Controller):
                     f"Plugin: {plugin_name} deployed successfully")
         else:
             self.app.log.error(f'plugin: {plugin_name} was not found')
+
+    @ex(
+        help="update base_crawler packages",
+        arguments=[
+            (['-b'], {
+                "help": "name of the base crawler you want to use",
+                "action": "store",
+                "dest": "base_plugin_name"
+            }),
+            (['-s'], {
+                "help": "name of target crawler that you want to use",
+                "action": "store",
+                "dest": "plugin_name"
+            })
+        ]
+    )
+    def use_basecrawler(self):
+        s3 = S3()
+
+        base_plugin_name = self.app.pargs.base_plugin_name
+        if('-' in base_plugin_name):
+            version = base_plugin_name.split('-')[1]
+            base_plugin_name = base_plugin_name.split('-')[0]
+
+        base_plugin_dir_path = get_plugin_path(
+            base_plugin_name, type='php')
+        target_plugin_name = self.app.pargs.plugin_name
+        target_plugin_path = get_plugin_path(
+            target_plugin_name, type='php'
+        )
+
+        if(base_plugin_dir_path):
+            f = open(f"{base_plugin_dir_path}/.version", mode='r')
+            version = f.read()
+            f.close()
+
+            Log.info(
+                f'Getting Secure Url of target plugin: {base_plugin_name}, {version}')
+
+            presigned_url = s3.get_secure_url(bucket='crawler-plugins',
+                                              filename=f'php/vortex-plugins-services-base/{base_plugin_name}/{base_plugin_name}-{version}.tar.gz')
+            if(target_plugin_path):
+                data = {
+                    'presigned_url': presigned_url,
+                    'plugin_name': base_plugin_name,
+                    'version': version
+                }
+
+                render_boilerplate(boilerplate='composer.jinja2', data=data,
+                                   destination_path=target_plugin_path + '/composer.json')
+                system(
+                    f""" cd {target_plugin_path} &&  composer install""")
\ No newline at end of file
